<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @since      1.0
 * @package    Leadferno
 * @subpackage Leadferno/admin
 */

class Leadferno_Admin
{
	/**
	 * The plugin options.
	 *
	 * @since	1.0
	 * @access 	private
	 * @var 	string 			$options    The plugin options.
	 */
	private $options;

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0
	 * @param    string    $plugin_name       The name of this plugin.
	 * @param    string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0
	 */
	public function enqueue_styles()
	{
		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/leadferno-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0
	 */
	public function enqueue_scripts()
	{
		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/leadferno-admin.js', array('jquery'), $this->version, false);
	}

	/**
	 * Sanitizes plugin options.
	 *
	 * @since 	 1.0
	 * @param 	 array 		$input 			array of submitted plugin options
	 * @return 	 array 						array of validated plugin options
	 */
	private function sanitizer($type, $data)
	{
		if (empty($type)) {
			return;
		}

		if (empty($data)) {
			return;
		}

		$return = '';
		$sanitizer = new Leadferno_Sanitize();

		$sanitizer->set_data($data);
		$sanitizer->set_type($type);

		$return = $sanitizer->clean();

		unset($sanitizer);

		return $return;
	}

	/**
	 * Validates saved options.
	 *
	 * @since 	 1.0
	 * @param 	 array 		$input 			array of submitted plugin options
	 * @return 	 array 						array of validated plugin options
	 */
	public function validate_options($input)
	{
		//wp_die( print_r( $input ) );

		$valid = array();
		$options = $this->get_options_list();

		foreach ($options as $option) {
			$name = $option[0];
			$type = $option[1];

			$valid[$option[0]] = $this->sanitizer($type, $input[$name]);
		}

		return $valid;
	}

	/**
	 * Create a new custom post type (leadbox) - Master.
	 *
	 * @since 	 1.0
	 */
	public static function leadbox_register_post_type()
	{
		$cap_type = 'post';
		$global_name = 'Leadferno';
		$plural = 'Leadboxes';
		$single = 'Leadbox';
		$post_name = 'leadbox';

		$opts['description'] = '';
		$opts['public'] = FALSE;
		$opts['hierarchical'] = FALSE;
		$opts['exclude_from_search'] = TRUE;
		$opts['publicly_querable'] = FALSE;
		$opts['show_ui'] = TRUE;
		$opts['show_in_menu'] = TRUE;
		$opts['show_in_nav_menus'] = FALSE;
		$opts['show_in_admin_bar'] = TRUE;
		$opts['menu_position'] = 25;
		$opts['menu_icon'] = 'dashicons-admin-generic';
		$opts['capability_type'] = $cap_type;
		$opts['map_meta_cap'] = TRUE;
		$opts['supports'] = array('title');
		$opts['register_meta_box_cb'] = '';
		$opts['taxonomies'] = array();
		$opts['has_archive'] = FALSE;
		$opts['rewrite'] = FALSE;
		$opts['query_var'] = FALSE;
		$opts['can_export'] = FALSE;

		// Capabilities
		$opts['capabilities']['delete_others_posts'] = "delete_others_{$cap_type}s";
		$opts['capabilities']['delete_post'] = "delete_{$cap_type}";
		$opts['capabilities']['delete_posts'] = "delete_{$cap_type}s";
		$opts['capabilities']['delete_private_posts']	= "delete_private_{$cap_type}s";
		$opts['capabilities']['delete_published_posts']	= "delete_published_{$cap_type}s";
		$opts['capabilities']['edit_others_posts'] = "edit_others_{$cap_type}s";
		$opts['capabilities']['edit_post'] = "edit_{$cap_type}";
		$opts['capabilities']['edit_posts'] = "edit_{$cap_type}s";
		$opts['capabilities']['edit_private_posts'] = "edit_private_{$cap_type}s";
		$opts['capabilities']['edit_published_posts']	= "edit_published_{$cap_type}s";
		$opts['capabilities']['publish_posts'] = "publish_{$cap_type}s";
		$opts['capabilities']['read_post'] = "read_{$cap_type}";
		$opts['capabilities']['read_private_posts'] = "read_private_{$cap_type}s";

		// Labels
		$opts['labels']['add_new'] = esc_html__("Add New {$single}", 'leadferno');
		$opts['labels']['add_new_item'] = esc_html__("Add New {$single}", 'leadferno');
		$opts['labels']['all_items'] = esc_html__($plural, 'leadferno');
		$opts['labels']['edit_item'] = esc_html__("Edit {$single}", 'leadferno');
		$opts['labels']['menu_name'] = esc_html__($global_name, 'leadferno');
		$opts['labels']['name'] = esc_html__($plural, 'leadferno');
		$opts['labels']['name_admin_bar'] = esc_html__($single, 'leadferno');
		$opts['labels']['new_item'] = esc_html__("New {$single}", 'leadferno');
		$opts['labels']['not_found'] = esc_html__("No {$plural} Found", 'leadferno');
		$opts['labels']['not_found_in_trash'] = esc_html__("No {$plural} Found in Trash", 'leadferno');
		$opts['labels']['parent_item_colon'] = esc_html__("Parent {$plural} :", 'leadferno');
		$opts['labels']['search_items'] = esc_html__("Search {$plural}", 'leadferno');
		$opts['labels']['singular_name'] = esc_html__($single, 'leadferno');
		$opts['labels']['view_item'] = esc_html__("View {$single}", 'leadferno');

		$opts = apply_filters('leadbox-options', $opts);

		register_post_type(strtolower($post_name), $opts);
	}
}
